# package_name

Description. 
The package image_processing_01 is used to:
	Processing:
		-Histogram matching
		-Structural similarity
		-Resize image
	Utils
		-Read image
		-Save image
		-Plot image
		-Plot result
		-Plot histogram
## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install image_processing_01
```

## Author
Rafael

## License
[MIT](https://choosealicense.com/licenses/mit/)